==> blancoTmx-0.0.1-src.zip: blancoTmx/blanco/main/blanco/tmx/valueobject/BlancoTmxHeader.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.tmx.valueobject;

/**
 * LISA TMX  headervf킷o[IuWFNgB
 */
public class BlancoTmxHeader {
    /**
     * tB[h [creationtool]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["blancoTmx"]<br>
     */
    private String fCreationtool = "blancoTmx";

    /**
     * tB[h [creationtoolversion]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["0.0.1"]<br>
     */
    private String fCreationtoolversion = "0.0.1";

    /**
     * tB[h [segtype]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["block"]<br>
     * &quot;block&quot;, &quot;paragraph&quot;, &quot;sentence&quot;, &quot;phrase&quot;
     */
    private String fSegtype = "block";

    /**
     * tB[h [o-tmf]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["XLIFF"]<br>
     * IWitH[}bgB
     */
    private String fOTmf = "XLIFF";

    /**
     * tB[h [adminlang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["ja_JP"]<br>
     * ftHgB
     */
    private String fAdminlang = "ja_JP";

    /**
     * tB[h [srclang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["*all*"]<br>
     * \[XB
     */
    private String fSrclang = "*all*";

    /**
     * tB[h [datatype]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["unknown"]<br>
     * f[^^CvB
     */
    private String fDatatype = "unknown";

    /**
     * tB[h [creationtool]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argCreationtool tB[h[creationtool]Ɋi[l
     */
    public void setCreationtool(final String argCreationtool) {
        fCreationtool = argCreationtool;
    }

    /**
     * tB[h[creationtool]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["blancoTmx"]<br>
     *
     * @return tB[h[creationtool]Ɋi[Ăl
     */
    public String getCreationtool() {
        return fCreationtool;
    }

    /**
     * tB[h [creationtoolversion]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argCreationtoolversion tB[h[creationtoolversion]Ɋi[l
     */
    public void setCreationtoolversion(final String argCreationtoolversion) {
        fCreationtoolversion = argCreationtoolversion;
    }

    /**
     * tB[h[creationtoolversion]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["0.0.1"]<br>
     *
     * @return tB[h[creationtoolversion]Ɋi[Ăl
     */
    public String getCreationtoolversion() {
        return fCreationtoolversion;
    }

    /**
     * tB[h [segtype]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * &quot;block&quot;, &quot;paragraph&quot;, &quot;sentence&quot;, &quot;phrase&quot;
     *
     * @param argSegtype tB[h[segtype]Ɋi[l
     */
    public void setSegtype(final String argSegtype) {
        fSegtype = argSegtype;
    }

    /**
     * tB[h[segtype]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["block"]<br>
     * &quot;block&quot;, &quot;paragraph&quot;, &quot;sentence&quot;, &quot;phrase&quot;
     *
     * @return tB[h[segtype]Ɋi[Ăl
     */
    public String getSegtype() {
        return fSegtype;
    }

    /**
     * tB[h [o-tmf]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * IWitH[}bgB
     *
     * @param argOTmf tB[h[o-tmf]Ɋi[l
     */
    public void setOTmf(final String argOTmf) {
        fOTmf = argOTmf;
    }

    /**
     * tB[h[o-tmf]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["XLIFF"]<br>
     * IWitH[}bgB
     *
     * @return tB[h[o-tmf]Ɋi[Ăl
     */
    public String getOTmf() {
        return fOTmf;
    }

    /**
     * tB[h [adminlang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ftHgB
     *
     * @param argAdminlang tB[h[adminlang]Ɋi[l
     */
    public void setAdminlang(final String argAdminlang) {
        fAdminlang = argAdminlang;
    }

    /**
     * tB[h[adminlang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["ja_JP"]<br>
     * ftHgB
     *
     * @return tB[h[adminlang]Ɋi[Ăl
     */
    public String getAdminlang() {
        return fAdminlang;
    }

    /**
     * tB[h [srclang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XB
     *
     * @param argSrclang tB[h[srclang]Ɋi[l
     */
    public void setSrclang(final String argSrclang) {
        fSrclang = argSrclang;
    }

    /**
     * tB[h[srclang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["*all*"]<br>
     * \[XB
     *
     * @return tB[h[srclang]Ɋi[Ăl
     */
    public String getSrclang() {
        return fSrclang;
    }

    /**
     * tB[h [datatype]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * f[^^CvB
     *
     * @param argDatatype tB[h[datatype]Ɋi[l
     */
    public void setDatatype(final String argDatatype) {
        fDatatype = argDatatype;
    }

    /**
     * tB[h[datatype]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["unknown"]<br>
     * f[^^CvB
     *
     * @return tB[h[datatype]Ɋi[Ăl
     */
    public String getDatatype() {
        return fDatatype;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.tmx.valueobject.BlancoTmxHeader[");
        buf.append("creationtool=" + fCreationtool);
        buf.append(",creationtoolversion=" + fCreationtoolversion);
        buf.append(",segtype=" + fSegtype);
        buf.append(",o-tmf=" + fOTmf);
        buf.append(",adminlang=" + fAdminlang);
        buf.append(",srclang=" + fSrclang);
        buf.append(",datatype=" + fDatatype);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoTmx-0.0.6-src.zip: blancoTmx/blanco/main/blanco/tmx/valueobject/BlancoTmxHeader.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.tmx.valueobject;

/**
 * LISA TMX  headervf킷o[IuWFNgB
 */
public class BlancoTmxHeader {
    /**
     * tB[h [creationtool]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["blancoTmx"]<br>
     */
    private String fCreationtool = "blancoTmx";

    /**
     * tB[h [creationtoolversion]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["0.0.1"]<br>
     */
    private String fCreationtoolversion = "0.0.1";

    /**
     * tB[h [segtype]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["block"]<br>
     * &quot;block&quot;, &quot;paragraph&quot;, &quot;sentence&quot;, &quot;phrase&quot;
     */
    private String fSegtype = "block";

    /**
     * tB[h [o-tmf]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["XLIFF"]<br>
     * IWitH[}bgB
     */
    private String fOTmf = "XLIFF";

    /**
     * tB[h [adminlang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["ja-jp"]<br>
     * ftHgB&quot;ja-jp&quot;LISAQƁB
     */
    private String fAdminlang = "ja-jp";

    /**
     * tB[h [srclang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["EN"]<br>
     * \[XB&quot;*all*&quot; ߂ &quot;EN&quot; ɕύXB
     */
    private String fSrclang = "EN";

    /**
     * tB[h [datatype]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["unknown"]<br>
     * f[^^CvB
     */
    private String fDatatype = "unknown";

    /**
     * tB[h [creationtool]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argCreationtool tB[h[creationtool]Ɋi[l
     */
    public void setCreationtool(final String argCreationtool) {
        fCreationtool = argCreationtool;
    }

    /**
     * tB[h[creationtool]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["blancoTmx"]<br>
     *
     * @return tB[h[creationtool]Ɋi[Ăl
     */
    public String getCreationtool() {
        return fCreationtool;
    }

    /**
     * tB[h [creationtoolversion]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     *
     * @param argCreationtoolversion tB[h[creationtoolversion]Ɋi[l
     */
    public void setCreationtoolversion(final String argCreationtoolversion) {
        fCreationtoolversion = argCreationtoolversion;
    }

    /**
     * tB[h[creationtoolversion]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["0.0.1"]<br>
     *
     * @return tB[h[creationtoolversion]Ɋi[Ăl
     */
    public String getCreationtoolversion() {
        return fCreationtoolversion;
    }

    /**
     * tB[h [segtype]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * &quot;block&quot;, &quot;paragraph&quot;, &quot;sentence&quot;, &quot;phrase&quot;
     *
     * @param argSegtype tB[h[segtype]Ɋi[l
     */
    public void setSegtype(final String argSegtype) {
        fSegtype = argSegtype;
    }

    /**
     * tB[h[segtype]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["block"]<br>
     * &quot;block&quot;, &quot;paragraph&quot;, &quot;sentence&quot;, &quot;phrase&quot;
     *
     * @return tB[h[segtype]Ɋi[Ăl
     */
    public String getSegtype() {
        return fSegtype;
    }

    /**
     * tB[h [o-tmf]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * IWitH[}bgB
     *
     * @param argOTmf tB[h[o-tmf]Ɋi[l
     */
    public void setOTmf(final String argOTmf) {
        fOTmf = argOTmf;
    }

    /**
     * tB[h[o-tmf]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["XLIFF"]<br>
     * IWitH[}bgB
     *
     * @return tB[h[o-tmf]Ɋi[Ăl
     */
    public String getOTmf() {
        return fOTmf;
    }

    /**
     * tB[h [adminlang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ftHgB&quot;ja-jp&quot;LISAQƁB
     *
     * @param argAdminlang tB[h[adminlang]Ɋi[l
     */
    public void setAdminlang(final String argAdminlang) {
        fAdminlang = argAdminlang;
    }

    /**
     * tB[h[adminlang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["ja-jp"]<br>
     * ftHgB&quot;ja-jp&quot;LISAQƁB
     *
     * @return tB[h[adminlang]Ɋi[Ăl
     */
    public String getAdminlang() {
        return fAdminlang;
    }

    /**
     * tB[h [srclang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * \[XB&quot;*all*&quot; ߂ &quot;EN&quot; ɕύXB
     *
     * @param argSrclang tB[h[srclang]Ɋi[l
     */
    public void setSrclang(final String argSrclang) {
        fSrclang = argSrclang;
    }

    /**
     * tB[h[srclang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["EN"]<br>
     * \[XB&quot;*all*&quot; ߂ &quot;EN&quot; ɕύXB
     *
     * @return tB[h[srclang]Ɋi[Ăl
     */
    public String getSrclang() {
        return fSrclang;
    }

    /**
     * tB[h [datatype]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * f[^^CvB
     *
     * @param argDatatype tB[h[datatype]Ɋi[l
     */
    public void setDatatype(final String argDatatype) {
        fDatatype = argDatatype;
    }

    /**
     * tB[h[datatype]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   ["unknown"]<br>
     * f[^^CvB
     *
     * @return tB[h[datatype]Ɋi[Ăl
     */
    public String getDatatype() {
        return fDatatype;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.tmx.valueobject.BlancoTmxHeader[");
        buf.append("creationtool=" + fCreationtool);
        buf.append(",creationtoolversion=" + fCreationtoolversion);
        buf.append(",segtype=" + fSegtype);
        buf.append(",o-tmf=" + fOTmf);
        buf.append(",adminlang=" + fAdminlang);
        buf.append(",srclang=" + fSrclang);
        buf.append(",datatype=" + fDatatype);
        buf.append("]");
        return buf.toString();
    }
}
